@@ -144,6 +144,7 @@ class NamespaceDict(dict):
         NamespaceDict(**kwargs) -> new namespaced dictionary initialized with the name=value pairs
             in the keyword argument list.  For example:  NamespaceDict(one=1, two=2)
         """
+        super().__init__()
         if seq is not None:
             for k in seq:
                 self[k] = seq[k]
@@ -218,7 +219,7 @@ class FileDict(Mapping):
 
     def __getitem__(self, k):
         with open(self.cache, "rb+") as fh_:
-            return msgpack.loads(fh_)[k]
+            return msgpack.loads(fh_.read())[k]
 
     async def __aiter__(self):
         async with aiofiles.open(self.cache, "rb+") as fh_:
